#
# spec file for package python-ephem
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ephem
Version:        4.1.5
Release:        1.3
Summary:        Scientific-grade astronomy routines for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/brandon-rhodes/pyephem
Source0:        https://files.pythonhosted.org/packages/source/e/ephem/ephem-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytzdata}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytzdata
%python_subpackages

%description
PyEphem provides an ephem Python package for performing high-precision astronomy computations.

%prep
%setup -q -n ephem-%{version}
# disable failing doctests
rm ephem/tests/test_rst.py
# remove shebangs in test files
sed -i '1{/env python/d}' ephem/tests/test_*.py

%build
export LANG=en_US.UTF8
%python_build

%install
export LANG=en_US.UTF8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF8
mkdir emptytestdir
pushd emptytestdir
%pyunittest_arch discover -v ephem.tests
popd

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/ephem
%{python_sitearch}/ephem-%{version}*-info

%changelog
* Mon Dec  4 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.5:
  * Add support for Python 3.12.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.4:
  * A memory leak has been resolved, that was failing to free the storage
  for the satellite name (a Python string) and catalog number (a Python
  integer) when the satellite object itself was freed.
  * In previous versions, if you asked for the position of a body
  (a) whose elliptical or hyperbolic orbit has an eccentricity very
  close to 1.0 and (b) which is very far from perihelion, then the
  underlying C library would print a warning ``Near-parabolic orbit:
  inaccurate result`` but let your Python script continue on unawares.
  Now, no message is printed directly to the screen, and instead a
  ``RuntimeError`` will tell you why PyEphem can’t compute the body’s
  position.
  * The underlying C library should no longer produce a segmentation fault
  if given the floating point number ``NaN`` as a date.  The Python
  rising and setting logic now also watches out for ``NaN`` dates, and
  raises a ``ValueError`` when one is detected.
* Mon Jan 17 2022 Ben Greiner <code@bnavigator.de>
- Update to 4.1.3
  * Fixed an inadvertent loss of precision in the routine that
    computes a date’s hours, minutes, and seconds.  It was
    sometimes returning a small negative number of seconds, which
    caused Python’s `datetime` type to complain `ValueError: second
    must be in 0..59`.
- Release 4.1.2
  * Fixed the new rising and setting routines so they properly
    detect if a body is always below the horizon and raise a
    NeverUpError instead of a plain ValueError.
  * Gave bodies a new ha Hour Angle attribute, since the quantity
    was computed internally but then discarded.
  * Renamed the observer attribute temp to temperature, leaving an
    alias behind to support the old spelling.
* Mon Jan 17 2022 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * When you provide PyEphem with a Python ``datetime`` that has a time
  zone attached, PyEphem now detects the time zone and converts the date
  and time to UTC automatically.
  * A new search routine had been written and tested
  to power the :ref:`transit-rising-setting` methods
  ``previous_rising()``,
  ``previous_setting()``,
  ``next_rising()``, and
  ``next_setting()``.
  They should no longer be susceptible to getting hung up in a loop.
  You should also find them substantially faster.
  * Fixed the ``constellation()`` routine so that it uses astrometric,
  rather than apparent, right ascension and declination.  This should
  make it more accurate along the borders of each constellation.
  * Fixed how the underlying “libastro” library computes whether a body’s
  image is deflected by gravity when its light passes close to the Sun.
  Previously, users would see coordinates jump unexpectedly as the
  deflection formula turned on and off haphazardly.
  * Fixed the star positions in the ``ephem.stars`` star catalog by adding
  8.75 years of proper motion to each star.  Previously, each 1991.25
  position from the Hipparcos catalog was being incorrectly treated as a
  2000.0 position.
  * A new routine ``unrefract()`` lets you compute the real altitude
  of a body that you observe in the sky at a given apparent altitude.
  * The old ``cities.lookup()`` function is now officially deprecated.
  Because of a Google API restriction, it stopped working in 2018.
  * Planetary moon positions are now available through the year 2040
  (previously, asking for a position past 2020 returned zeroes).
  * The ``Date`` object is improved such that the return values of
  ``str(d)``, ``d.datetime()``, and ``d.tuple()`` always agree and are
  always rounded to the nearest microsecond.
  * Earth satellites offer new orbit parameter attributes.  The old names
  (which are still present, but no longer documented) started awkwardly
  with underscores, and had inconsistent getters and setters that would
  change the satellite if you attempted a round trip like ``sat._inc =
  sat._inc``.  The new attributes (see the list in the Quick Reference)
  have simple names and use the same units when getting and setting.
  * Updated Pluto’s long-term orbital elements
  to match the Astronomical Almanac 2020.
  * Fixed the body ``copy()`` method to correct copy the extra attributes
  * that some bodies have beyond those of a normal body, like the catalog
  * number of an Earth satellite.  This bug had made core dumps possible.
  * Expanded the ∆T table so that it now runs through 2018,
  with data from the Astronomical Almanac 2020.
  * The ``Observer.copy()`` method is now documented,
  and (after a user requested it)
  the class also now works with Python’s ``copy`` module.
  * PyEphem should now be able to compile for pypy3.
  * Restore PyEphem’s undocumented ability to parse angle strings like
  ``'12 34 56'`` that are only separated with spaces, instead of
  insisting on ``'12:34:56'`` for 12 degrees, 34 arcminutes, and 56
  arcseconds.
  * Fix a compile error `‘for’ loop initial declarations are only allowed
  in C99 mode` reported from a user on Oracle Linux.
  * Fix ``MANIFEST.in`` so the ``.tar.gz`` source distribution includes
  all the header files necessary for compilation.
  * Upgraded to the MIT license following Elwood Downey’s generous
  decision to open-source XEphem’s code.
  * Fix a bug where supplying a string with a decimal degree measurement
  could send the parser into an infinite loop.
  * The ``FixedBody`` constructor, which accepts no arguments, now
  correctly raises a ``TypeError`` if any are supplied.
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.7.7.1:
  * Fixed a memory leak in ``readdb()``.
  * Fixed the ``Body.copy()`` method to correctly copy
  object-specific fields across to the new object, like Saturn ring tilt
  and Earth satellite catalog number.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by the convertdate
